// Set up dimensions for the chart
const margin = {
  top: 20,
  right: 30,
  bottom: 40,
  left: 100,
};
const width = 800 - margin.left - margin.right;
const height = 400 - margin.top - margin.bottom;

// Append SVG to the chart container
const svg = d3
  .select('#chart-container')
  .append('svg')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    `translate(${margin.left},${margin.top})`,
  );

// Load data from CSV file
d3.csv(
  'https://gist.githubusercontent.com/AsheshPinisetti/ed9b0f37f188b480a6318223bde6978a/raw/3df499fa457dab7571db918e743bd328e68bfd11/salaries.csv',
)
  .then((data) => {
    // Group data by experience level and employment type, calculate average salary
    const nestedData = d3.group(
      data,
      (d) => d.experience_level + '|' + d.employment_type,
    );
    const averages = Array.from(
      nestedData,
      ([key, values]) => ({
        key,
        averageSalary: d3.mean(
          values,
          (d) => +d.salary_in_usd,
        ),
        employmentType: key.split('|')[1],
      }),
    );

    // Sort data by employment type
    averages.sort((a, b) =>
      d3.ascending(a.employmentType, b.employmentType),
    );

    // Define color scale for employment types
    const color = d3
      .scaleOrdinal()
      .domain(data.map((d) => d.employment_type))
      .range(d3.schemeCategory10);

    // Define x scale
    const x = d3
      .scaleLinear()
      .domain([0, d3.max(averages, (d) => d.averageSalary)])
      .range([0, width]);

    // Define y scale
    const y = d3
      .scaleBand()
      .domain(averages.map((d) => d.key))
      .range([0, height])
      .padding(0.1);

    // Append bars to the SVG
    svg
      .selectAll('.bar')
      .data(averages)
      .enter()
      .append('rect')
      .attr('class', 'bar')
      .attr('x', 0)
      .attr('y', (d) => y(d.key))
      .attr('width', (d) => x(d.averageSalary))
      .attr('height', y.bandwidth())
      .attr('fill', (d) => color(d.employmentType));

    // Append y-axis
    svg
      .append('g')
      .attr('class', 'y-axis')
      .call(d3.axisLeft(y));

    // Append x-axis
    svg
      .append('g')
      .attr('class', 'x-axis')
      .attr('transform', `translate(0,${height})`)
      .call(d3.axisBottom(x));

    // Append legend
    const legend = svg
      .selectAll('.legend')
      .data(data.map((d) => d.employment_type))
      .enter()
      .append('g')
      .attr('class', 'legend')
      .attr(
        'transform',
        (d, i) => `translate(0,${i * 20})`,
      );

    legend
      .append('rect')
      .attr('x', width + 10)
      .attr('width', 18)
      .attr('height', 18)
      .style('fill', color);

    legend
      .append('text')
      .attr('x', width + 35)
      .attr('y', 9)
      .attr('dy', '.35em')
      .style('text-anchor', 'start')
      .text((d) => d);
  })
  .catch((error) =>
    console.error('Error loading the data:', error),
  );
